@@ -1,4 +1,5 @@
 import argparse
+
 from domains_api.constants import __VERSION__
 
 
@@ -45,7 +46,7 @@ parser.add_argument(
     "-E",
     "--test-email",
     action="store_true",
-    help="send a test email with current credentials"
+    help="send a test email with current credentials",
 )
 parser.add_argument(
     "-d",
