@@ -2,8 +2,7 @@ import os
 
 from cryptography.fernet import Fernet
 
-
-file = os.path.join(os.path.dirname(__file__), 'fnet')
+file = os.path.join(os.path.dirname(__file__), "fnet")
 
 if not os.path.exists(file):
     key = Fernet.generate_key()
@@ -17,4 +16,4 @@ encrypter = Fernet(key)
 
 
 def decrypt_password(password: bytes):
-    return encrypter.decrypt(password).decode()
\ No newline at end of file
+    return encrypter.decrypt(password).decode()
